【重要】资源查询必须遵循的流程：
1. 当用户询问任何资源相关信息时，必须首先调用 `list_queryable_assets` 函数查看 `list_queryable_assets` 的输出，确认用户询问的资源类型是否存在
2. 如果资源类型存在，再调用相应的 `list_assets` 查看对应资源的列表，匹配用户的查询条件找到最相关的资源
3. 如果资源类型不存在，告知用户该资源类型不支持，并展示可用的资源类型
4. 如果用户对资源的操作类型不支持，告知用户该操作类型不支持，并展示可用的操作类型